@@ -24,7 +24,7 @@ for k = 1:numel (list {1}.provides)
         fprintf (fid, '@chapter %s\n', group.category);
         
         for k=1:numel(functions)
-                [TEXT, FORMAT] = get_help_text (functions(k));
+                [TEXT, FORMAT] = get_help_text (functions{k});
                 fun = functions{k};
                 if (fun(1) == "@")
                   % fprintf (fid, '@subsection @%s\n', fun);
